@@ -5,11 +5,13 @@ import click
 
 from twyn.__version__ import __version__
 from twyn.base.constants import (
+    DEFAULT_PROJECT_TOML_FILE,
     DEPENDENCY_FILE_MAPPING,
     SELECTOR_METHOD_MAPPING,
     AvailableLoggingLevels,
 )
 from twyn.config.config_handler import ConfigHandler
+from twyn.file_handler.file_handler import FileHandler
 from twyn.main import check_dependencies
 
 
@@ -84,13 +86,15 @@ def run(
     if dependency_file and not any(dependency_file.endswith(key) for key in DEPENDENCY_FILE_MAPPING):
         raise click.UsageError("Dependency file name not supported.", ctx=click.get_current_context())
 
-    return int(
-        check_dependencies(
-            config_file=config,
-            dependency_file=dependency_file,
-            dependencies_cli=set(dependency) or None,
-            selector_method=selector_method,
-            verbosity=verbosity,
+    sys.exit(
+        int(
+            check_dependencies(
+                config_file=config,
+                dependency_file=dependency_file,
+                dependencies_cli=set(dependency) or None,
+                selector_method=selector_method,
+                verbosity=verbosity,
+            )
         )
     )
 
@@ -101,15 +105,19 @@ def allowlist() -> None:
 
 
 @allowlist.command()
+@click.option("--config", type=click.STRING)
 @click.argument("package_name")
-def add(package_name: str) -> None:
-    ConfigHandler().add_package_to_allowlist(package_name)
+def add(package_name: str, config: str) -> None:
+    fh = FileHandler(config or DEFAULT_PROJECT_TOML_FILE)
+    ConfigHandler(fh).add_package_to_allowlist(package_name)
 
 
 @allowlist.command()
+@click.option("--config", type=click.STRING)
 @click.argument("package_name")
-def remove(package_name: str) -> None:
-    ConfigHandler().remove_package_from_allowlist(package_name)
+def remove(package_name: str, config: str) -> None:
+    fh = FileHandler(config or DEFAULT_PROJECT_TOML_FILE)
+    ConfigHandler(fh).remove_package_from_allowlist(package_name)
 
 
 if __name__ == "__main__":
